# Berthold Höllmann's bhoelHelper module #

Some helper modules used in my other modules. 

## Description ##

  'check_args.py' -- 'CheckArgs' is used to process parameters for
	functions and class methods. It handels '*data' and
	'**keyword' arguments.

  'machar.py' -- 'machar' is a python implementation of the machar
	routine from "Numerical recipes in C". It determines and makes
	avaible the machine specific parameters affecting floating
	point arithmetic.

# Installation #

pip install bhoelHelper

## Documentation ##
=============

  Only avaible documentations are the generated documentation. I used
  "HappyDoc":http://sourceforge.net/projects/happydoc/ to generate
  documentation in directory doc.

  Send me a "email", mailto:bhoel@starship.python.net if you like
  this, or have any comments.
